# X NLP

Python library of helper functions for Natural Language Processing related algorithms (designed for the course).

## Installation

haha pip go brrr:
```sh
pip install x-nlp
```

## Modules

This package contains various modules, each responsible for assisting students in completing a given [Homework Problem](https://github.com/techx-nlp/homework). Some of the modules are more general-purposed, and (hopefully) can be useful outside of the assignments of this course.

An overview of modules that this package has to offer:
- `xnlp.parser`: Parser combinators (token-based) for parse tree generation
